==> em_tasks-0.1.58-py2.py3-none-any.whl: em_tasks/tools/spree/sheet_orders_importer.py <==
# -*- coding: utf-8 -*-

import re
import datetime

from gspread.exceptions import APIError
from tracking_numbers import get_tracking_number

from em_tasks import logger
from em_tasks.store.store_util import StoreUtil
from em_tasks.google.sheet_api import SheetAPI
from em_tasks.utils.order_reader import GSheetOrderReader
from em_tasks.store.models import *
from em_tasks.tools.orders_sheet_base import OrdersSheetBase
from em_tasks.spree.api import SpreeApi


class SheetOrdersImporter(OrdersSheetBase):
  def __init__(self, store_code, service_account_data, days):
    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return

    credential = json.loads(self.store.api_credential)
    self.spree_api = SpreeApi(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
    # self.spree_api = SpreeApi('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

    self.service_account_data = service_account_data
    self.sheet_api = SheetAPI(service_account_data)
    self.order_reader = GSheetOrderReader(self.sheet_api)
    self.days = days
    self.tracking_pattern = re.compile('[0-9A-Za-z-]{10,100}')
    self.dangdang_sheet_id = None
    spreadsheet_ids = dict()
    for spreadsheets in self.__class__.spreadsheet_ids.values():
      for source, spreadsheet_id in spreadsheets.items():
        spreadsheet_ids[spreadsheet_id] = None
        if not self.dangdang_sheet_id:
          if source.lower() == 'dangdang':
            self.dangdang_sheet_id = spreadsheet_id
    self.spreadsheet_ids = list(spreadsheet_ids.keys())

  def run(self):
    for spreadsheet_id in self.spreadsheet_ids:
      is_dangdang = spreadsheet_id == self.dangdang_sheet_id
      for worksheet, headers, orders in self.order_reader.read(spreadsheet_id, self.days):
        records = []
        for order in orders:
          order_id = order.get('order-id', '')
          if not order_id:
            continue

          order_id_valid = True
          for part in order_id.split('-'):
            if not part.isnumeric():
              order_id_valid = False
              break
          if not order_id_valid:
            continue

          external_order_number = order.get('order number', order.get('amazon order number', '')).strip()
          external_order_cost = order.get('order cost', order.get('cost', '')).strip()
          external_order_date = order.get('order date', '')
          external_order_seller = order.get('seller', '')
          external_order_account = order.get('account', '')

          tracking = order.get('tracking number', order.get('tracking', '')).strip()
          if not self.tracking_pattern.match(tracking):
            tracking = ''

          if not (tracking or (external_order_number and external_order_cost) or external_order_date or external_order_seller):
            continue

          if external_order_cost:
            cost = None
            try:
              cost = round(float(external_order_cost), 2)
            except Exception as e:
              cost = 0
              try:
                for cost_str in external_order_cost.split("\n"):
                  cost_str = re.sub('[^0-9\.]', '', cost_str.strip())
                  cost += round(float(cost_str), 2)
              except:
                cost = None
                logger.warning('[InvalidCost] %s', order)

            try:
              price = float(order.get('price', 0))
              quantity = int(order.get('quantity', order.get('quantity-purchased', 0)))
              total_price = price * quantity
              if is_dangdang:
                if cost and total_price and cost > total_price:
                  cost = cost / 7
              else:
                if cost and total_price and cost > 1.5 * total_price:
                  cost = None
            except:
              pass

            if cost:
              external_order_cost = cost
          else:
            external_order_cost = None

          if 'ship to customer' in order:
            ship_to_customer = order.get('ship to customer', 'Y')
            stc = ship_to_customer.strip().lower() not in ['n', 'stw']
          else:
            remark = order.get('remark', '')
            stc = remark.strip().lower() == 'stc'

          carrier = order.get('carrier', '')
          if not carrier:
            if tracking:
              tracking_number = get_tracking_number(tracking)
              if tracking_number and tracking_number.courier:
                carrier = tracking_number.courier.code.upper()
              else:
                carrier = 'PARCELSAPP'

          s_order_id, s_line_item_id = order_id.split('-')
          records.append({
            'order_id': order_id,
            's_order_id': s_order_id,
            's_line_item_id': s_line_item_id,
            'stc': stc,
            'buy_order_number': external_order_number,
            'buy_order_date': external_order_date,
            'buy_account': external_order_account or external_order_seller,
            'buy_cost': external_order_cost,
            'buy_carrier': carrier,
            'buy_tracking': tracking
          })

        if not records:
          continue

        try:
          self.spree_api.add_fulfill_orders(records)
        except Exception as e:
          logger.exception(e)

==> em_tasks-0.1.63-py2.py3-none-any.whl: em_tasks/tools/spree/sheet_orders_importer.py <==
# -*- coding: utf-8 -*-

import re
import datetime

from gspread.exceptions import APIError
from tracking_numbers import get_tracking_number

from em_tasks import logger
from em_tasks.store.store_util import StoreUtil
from em_tasks.google.sheet_api import SheetAPI
from em_tasks.utils.order_reader import GSheetOrderReader
from em_tasks.store.models import *
from em_tasks.tools.orders_sheet_base import OrdersSheetBase
from em_tasks.spree.api import SpreeApi


class SheetOrdersImporter(OrdersSheetBase):
  def __init__(self, store_code, service_account_data, days):
    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return

    credential = json.loads(self.store.api_credential)
    self.spree_api = SpreeApi(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
    # self.spree_api = SpreeApi('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

    self.service_account_data = service_account_data
    self.sheet_api = SheetAPI(service_account_data)
    self.order_reader = GSheetOrderReader(self.sheet_api)
    self.days = days
    self.tracking_pattern = re.compile('[0-9A-Za-z-]{10,100}')
    self.dangdang_sheet_id = None
    spreadsheet_ids = dict()
    for spreadsheets in self.__class__.spreadsheet_ids.values():
      for source, spreadsheet_id in spreadsheets.items():
        spreadsheet_ids[spreadsheet_id] = None
        if not self.dangdang_sheet_id:
          if source.lower() == 'dangdang':
            self.dangdang_sheet_id = spreadsheet_id
    self.spreadsheet_ids = list(spreadsheet_ids.keys())

  def run(self):
    for spreadsheet_id in self.spreadsheet_ids:
      is_dangdang = spreadsheet_id == self.dangdang_sheet_id
      for worksheet, headers, orders in self.order_reader.read(spreadsheet_id, self.days):
        records = []
        for order in orders:
          order_id = order.get('order-id', '')
          if not order_id:
            continue

          order_id_valid = True
          for part in order_id.split('-'):
            if not part.isnumeric():
              order_id_valid = False
              break
          if not order_id_valid:
            continue

          external_order_number = order.get('order number', order.get('amazon order number', '')).strip()
          external_order_cost = order.get('order cost', order.get('cost', '')).strip()
          external_order_date = order.get('order date', '')
          external_order_seller = order.get('seller', '')
          external_order_account = order.get('account', '')

          tracking = order.get('tracking number', order.get('tracking', '')).strip()
          if not self.tracking_pattern.match(tracking):
            tracking = ''

          # if not (tracking or (external_order_number and external_order_cost) or external_order_date or external_order_seller):
          if not (tracking or external_order_number or external_order_cost or external_order_date or external_order_seller):
            continue

          if external_order_cost:
            cost = None
            try:
              cost = round(float(external_order_cost), 2)
            except Exception as e:
              cost = 0
              try:
                for cost_str in external_order_cost.split("\n"):
                  cost_str = re.sub('[^0-9\.]', '', cost_str.strip())
                  cost += round(float(cost_str), 2)
              except:
                cost = None
                logger.warning('[InvalidCost] %s', order)

            try:
              price = float(order.get('price', 0))
              quantity = int(order.get('quantity', order.get('quantity-purchased', 0)))
              total_price = price * quantity
              if is_dangdang:
                if cost and total_price and cost > total_price:
                  cost = cost / 7
              else:
                if cost and total_price and cost > 1.5 * total_price:
                  cost = None
            except:
              pass

            if cost:
              external_order_cost = cost
          else:
            external_order_cost = None

          if 'ship to customer' in order:
            ship_to_customer = order.get('ship to customer', 'Y')
            stc = ship_to_customer.strip().lower() not in ['n', 'stw']
          else:
            remark = order.get('remark', '')
            stc = remark.strip().lower() == 'stc'

          carrier = order.get('carrier', '')
          if not carrier:
            if tracking:
              tracking_number = get_tracking_number(tracking)
              if tracking_number and tracking_number.courier:
                carrier = tracking_number.courier.code.upper()
              else:
                carrier = 'PARCELSAPP'

          s_order_id, s_line_item_id = order_id.split('-')
          records.append({
            'order_id': order_id,
            's_order_id': s_order_id,
            's_line_item_id': s_line_item_id,
            'stc': stc,
            'buy_order_number': external_order_number,
            'buy_order_date': external_order_date,
            'buy_account': external_order_account or external_order_seller,
            'buy_cost': external_order_cost,
            'buy_carrier': carrier,
            'buy_tracking': tracking
          })

        if not records:
          continue

        try:
          self.spree_api.add_fulfill_orders(records)
        except Exception as e:
          logger.exception(e)
